> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #9DOF click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example
```
#include "dof9_hw.h"
#include "resources.h"
sbit LSM9DS1_EN at PORTB2_bit;
char tmp;
char text[150];
char xgID, magID;
extern sensor_t LSM9DS1;
char tempUpdateCnt;

static void Values_Init();
static void new_row( void );
static void new_column( void );

static void Values_Init()
{
    UART1_Write_Text("   Accel X   "); // 13 char long column width
    new_column();
    UART1_Write_Text("   Accel Y   ");
    new_column();
    UART1_Write_Text("   Accel Z   ");
    new_column();
    UART1_Write_Text("   Gyro X    ");
    new_column();
    UART1_Write_Text("   Gyro Y    ");
    new_column();
    UART1_Write_Text("   Gyro Z    ");
    new_column();
    UART1_Write_Text("   Mag X     ");
    new_column();
    UART1_Write_Text("   Mag Y     ");
    new_column();
    UART1_Write_Text("   Mag Z     ");
    new_column();
    UART1_Write_Text("   Temp.     ");
    new_row();
}

static void new_row( void )
{
    //UART1_Write_Text("\r\n");
    UART1_Write(13);
    UART1_Write(10);
}

static void new_column( void )
{
    UART1_Write_Text("    ");
}

static void Display_AccelValues()    //[mg]
{
    sprintf( text, "   %2.3f            %2.3f            %2.3f       ",
      1000.0f*LSM9DS1.accelX, 1000.0f*LSM9DS1.accelY, 1000.0f*LSM9DS1.accelZ );
    UART1_Write_Text(text);
}

static void Display_MagValues()    //[mG]
{

    sprintf( text, "   %2.3f           %2.3f        %2.3f      ",
      1000.0f*LSM9DS1.magX, 1000.0f*LSM9DS1.magY, 1000.0f*LSM9DS1.magZ );
    UART1_Write_Text(text);
}

static void Display_GyroValues()    //[deg/sec]
{
    sprintf( text, "   %2.3f          %2.3f           %2.3f        ",
      LSM9DS1.gyroX, LSM9DS1.gyroY, LSM9DS1.gyroZ );
    UART1_Write_Text(text);
}

static void Display_Temperature()    //[degrees C]
{
    sprintf( text, "   %.3f", LSM9DS1.temperature);
    UART1_Write_Text(text);
}

//------------------------------------------------------------------------------
// Calibration
//------------------------------------------------------------------------------
void calibration( void )
{
    xgID = LSM9DS1_GetGyroID();
    magID = LSM9DS1_GetMagID();
    
    if ( ( xgID == XG_ID ) && ( magID == MAG_ID ) )
    {
        UART1_Write_Text("Calibrating, please wait...");
        new_row();
    }
    else
    {
        UART1_Write_Text("Error");
        while( 1 ); //stop program
    }
    
    LSM9DS1_CalibrateXG();
    LSM9DS1_CalibrateMag();
    UART1_Write_Text("Calibrating done.");
    new_row();
    delay_ms( 500 );
    new_row();
    LSM9DS1_Init();
    delay_ms( 1000 );
    Values_Init();
    delay_ms( 100 );
}

/*******************************************************************************
* System init
*******************************************************************************/
static void System_Init()
{
    //GPIO_Digital_Input( &GPIOD_BASE, _GPIO_PINMASK_10 );
    //GPIO_Digital_Output( &GPIOC_BASE, _GPIO_PINMASK_2 );
    //GPIO_Digital_Input(&GPIO_PORT_00_07, _GPIO_PINMASK_0 | _GPIO_PINMASK_1);
    //GPIO_Digital_Output(&GPIO_PORT_00_07, _GPIO_PINMASK_0 | _GPIO_PINMASK_1);
    TWI_Init( 100000 );
    delay_ms( 200 );
    LSM9DS1_i2c_init( LSM9DS1M_ADDRESS, LSM9DS1XG_ADDRESS );
    delay_ms( 200 );
    UART1_Init(57600);               // Initialize UART module at 9600 bps
    Delay_ms(100);                  // Wait for UART module to stabilize
    new_row();
    UART_Write_Text( "9DOF Click [MikroElektronika] \r\n" );
}
```

```
/*******************************************************************************
* main function
*******************************************************************************/
void main()
{
    int counter = 0;
    System_Init();
    LSM9DS1_EN = 1;
    delay_ms( 10 );
    //Display_Init();
    //Check if LSM9DS1 chip present
    calibration();
    //LSM9DS1_ReadTemperatureData();
    //Display_Temperature();
    
    while( 1 )
    {
        if( LSM9DS1_AccelDataReady())
        {
            LSM9DS1_ReadAccelData();
            Display_AccelValues();
        }
        if( LSM9DS1_GyroDataReady())
        {
            LSM9DS1_ReadGyroData();
            Display_GyroValues();
        }
        if( LSM9DS1_MagDataReady())
        {
            LSM9DS1_ReadMagData();
            Display_MagValues();
        }
        //~1sec we update temperature value on display
        if ( tempUpdateCnt == 9)
        {
            LSM9DS1_ReadTemperatureData();
            Display_Temperature();
        }
        else
            tempUpdateCnt++;
        new_row();
        delay_ms( 100 );
    }
}
```